/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AggregationTemporality } from '@opentelemetry/sdk-metrics-base';
import { defaultOptions } from './OTLPMetricExporterOptions';
export class OTLPMetricExporterBase {
    constructor(exporter, config = defaultOptions) {
        var _a;
        this._otlpExporter = exporter;
        this._preferredAggregationTemporality = (_a = config.aggregationTemporality) !== null && _a !== void 0 ? _a : AggregationTemporality.CUMULATIVE;
    }
    export(metrics, resultCallback) {
        this._otlpExporter.export([metrics], resultCallback);
    }
    async shutdown() {
        await this._otlpExporter.shutdown();
    }
    forceFlush() {
        return Promise.resolve();
    }
    getPreferredAggregationTemporality() {
        return this._preferredAggregationTemporality;
    }
}
//# sourceMappingURL=OTLPMetricExporterBase.js.map