import { SpanAttributes } from '@opentelemetry/api';
import { otlpTypes } from '@opentelemetry/exporter-trace-otlp-http';
import { OTLPExporterBase, OTLPExporterConfigBase } from '@opentelemetry/otlp-exporter-base';
import { AggregationTemporality, MetricData, ResourceMetrics } from '@opentelemetry/sdk-metrics-base';
/**
 * Converts {@link SpanAttributes} to a collector-compatible format.
 * @param attributes
 */
export declare function toCollectorAttributes(attributes: SpanAttributes): otlpTypes.opentelemetryProto.common.v1.StringKeyValue[];
/**
 * Convert {@link AggregationTemporality} to a collector-compatible format.
 * @param aggregationTemporality
 */
export declare function toAggregationTemporality(aggregationTemporality: AggregationTemporality): otlpTypes.opentelemetryProto.metrics.v1.AggregationTemporality;
/**
 * Convert {@link MetricData} of {@link DataPointType.SINGULAR} to a collector-compatible format.
 * @param metricData
 */
export declare function toSingularDataPoints(metricData: MetricData): otlpTypes.opentelemetryProto.metrics.v1.DataPoint[];
/**
 * Convert {@link MetricData} of {@link DataPointType.HISTOGRAM} to a collector-compatible format.
 * @param metricData
 */
export declare function toHistogramDataPoints(metricData: MetricData): otlpTypes.opentelemetryProto.metrics.v1.HistogramDataPoint[];
/**
 * Converts {@link MetricData} to a collector-compatible format.
 * @param metricData
 * @param aggregationTemporality
 */
export declare function toCollectorMetric(metricData: MetricData, aggregationTemporality: AggregationTemporality): otlpTypes.opentelemetryProto.metrics.v1.Metric;
/**
 * Prepares metric service request to be sent to collector
 * @param metrics metrics
 * @param aggregationTemporality
 * @param collectorExporterBase
 */
export declare function toOTLPExportMetricServiceRequest<T extends OTLPExporterConfigBase>(metrics: ResourceMetrics, aggregationTemporality: AggregationTemporality, collectorExporterBase: OTLPExporterBase<T, ResourceMetrics, otlpTypes.opentelemetryProto.collector.metrics.v1.ExportMetricsServiceRequest>): otlpTypes.opentelemetryProto.collector.metrics.v1.ExportMetricsServiceRequest;
//# sourceMappingURL=transformMetrics.d.ts.map