"use strict";
/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OTLPMetricExporterBase = void 0;
const sdk_metrics_base_1 = require("@opentelemetry/sdk-metrics-base");
const OTLPMetricExporterOptions_1 = require("./OTLPMetricExporterOptions");
class OTLPMetricExporterBase {
    constructor(exporter, config = OTLPMetricExporterOptions_1.defaultOptions) {
        var _a;
        this._otlpExporter = exporter;
        this._preferredAggregationTemporality = (_a = config.aggregationTemporality) !== null && _a !== void 0 ? _a : sdk_metrics_base_1.AggregationTemporality.CUMULATIVE;
    }
    export(metrics, resultCallback) {
        this._otlpExporter.export([metrics], resultCallback);
    }
    async shutdown() {
        await this._otlpExporter.shutdown();
    }
    forceFlush() {
        return Promise.resolve();
    }
    getPreferredAggregationTemporality() {
        return this._preferredAggregationTemporality;
    }
}
exports.OTLPMetricExporterBase = OTLPMetricExporterBase;
//# sourceMappingURL=OTLPMetricExporterBase.js.map