"use strict";
/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OTLPMetricExporter = void 0;
const transformMetrics_1 = require("../../transformMetrics");
const core_1 = require("@opentelemetry/core");
const OTLPMetricExporterOptions_1 = require("../../OTLPMetricExporterOptions");
const OTLPMetricExporterBase_1 = require("../../OTLPMetricExporterBase");
const otlp_exporter_base_1 = require("@opentelemetry/otlp-exporter-base");
const DEFAULT_COLLECTOR_RESOURCE_PATH = '/v1/metrics';
const DEFAULT_COLLECTOR_URL = `http://localhost:4318${DEFAULT_COLLECTOR_RESOURCE_PATH}`;
class OTLPExporterNodeProxy extends otlp_exporter_base_1.OTLPExporterNodeBase {
    constructor(config = OTLPMetricExporterOptions_1.defaultOptions) {
        var _a;
        super(config);
        this.headers = Object.assign(this.headers, core_1.baggageUtils.parseKeyPairsIntoRecord((0, core_1.getEnv)().OTEL_EXPORTER_OTLP_METRICS_HEADERS));
        this._aggregationTemporality = (_a = config.aggregationTemporality) !== null && _a !== void 0 ? _a : OTLPMetricExporterOptions_1.defaultExporterTemporality;
    }
    convert(metrics) {
        return (0, transformMetrics_1.toOTLPExportMetricServiceRequest)(metrics[0], this._aggregationTemporality, this);
    }
    getDefaultUrl(config) {
        return typeof config.url === 'string'
            ? config.url
            : (0, core_1.getEnv)().OTEL_EXPORTER_OTLP_METRICS_ENDPOINT.length > 0
                ? (0, core_1.getEnv)().OTEL_EXPORTER_OTLP_METRICS_ENDPOINT
                : (0, core_1.getEnv)().OTEL_EXPORTER_OTLP_ENDPOINT.length > 0
                    ? (0, otlp_exporter_base_1.appendResourcePathToUrlIfNotPresent)((0, core_1.getEnv)().OTEL_EXPORTER_OTLP_ENDPOINT, DEFAULT_COLLECTOR_RESOURCE_PATH)
                    : DEFAULT_COLLECTOR_URL;
    }
}
/**
 * Collector Metric Exporter for Node
 */
class OTLPMetricExporter extends OTLPMetricExporterBase_1.OTLPMetricExporterBase {
    constructor(config = OTLPMetricExporterOptions_1.defaultOptions) {
        super(new OTLPExporterNodeProxy(config), config);
    }
}
exports.OTLPMetricExporter = OTLPMetricExporter;
//# sourceMappingURL=OTLPMetricExporter.js.map